@@ -15,7 +15,7 @@ class BuiltinTypesTest(unittest.TestCase):
     def tearDown(self):
         testutils.remove_project(self.project)
         super(BuiltinTypesTest, self).tearDown()
-    
+
     def test_simple_case(self):
         self.mod.write('l = []\n')
         pymod = self.pycore.resource_to_pyobject(self.mod)
@@ -42,13 +42,14 @@ class BuiltinTypesTest(unittest.TestCase):
         c_class = pymod['C'].get_object()
         a_var = pymod['a_var'].get_object()
         self.assertEquals(c_class, a_var.get_type())
-    
+
     def test_get_items_from_slices(self):
         self.mod.write('class C(object):\n    pass\nl = [C()]\na_var = l[:].pop()\n')
         pymod = self.pycore.resource_to_pyobject(self.mod)
         c_class = pymod['C'].get_object()
         a_var = pymod['a_var'].get_object()
         self.assertEquals(c_class, a_var.get_type())
+
     def test_simple_for_loops(self):
         self.mod.write('class C(object):\n    pass\nl = [C()]\n'
                        'for c in l:\n    a_var = c\n')
@@ -429,6 +430,13 @@ class BuiltinTypesTest(unittest.TestCase):
         self.mod.write(src)
         self.project.pycore.analyze_module(self.mod)
 
+    def test_abstractmethods_attribute(self):
+        # see http://bugs.python.org/issue10006 for details
+        src = 'class SubType(type): pass\nsubtype = SubType()\n'
+        self.mod.write(src)
+        self.project.pycore.analyze_module(self.mod)
+
+
 class BuiltinModulesTest(unittest.TestCase):
 
     def setUp(self):
