@@ -80,7 +80,7 @@ class CodeAssistTest(unittest.TestCase):
         result = self._assist(code)
         count = len([x for x in result
                      if x.name == 'variable' and x.scope == 'global'])
-        self.assertEquals(1, count)
+        self.assertEqual(1, count)
 
     @testutils.assert_raises(exceptions.ModuleSyntaxError)
     def test_throwing_exception_in_case_of_syntax_errors(self):
@@ -104,7 +104,7 @@ class CodeAssistTest(unittest.TestCase):
 
     def test_completion_result(self):
         code = 'my_global = 10\nt = my'
-        self.assertEquals(len(code) - 2, starting_offset(code, len(code)))
+        self.assertEqual(len(code) - 2, starting_offset(code, len(code)))
 
     def test_completing_imported_names(self):
         code = 'import sys\na = sy'
@@ -334,12 +334,12 @@ class CodeAssistTest(unittest.TestCase):
     def test_get_definition_location(self):
         code = 'def a_func():\n    pass\na_func()'
         result = get_definition_location(self.project, code, len(code) - 3)
-        self.assertEquals((None, 1), result)
+        self.assertEqual((None, 1), result)
 
     def test_get_definition_location_underlined_names(self):
         code = 'def a_sample_func():\n    pass\na_sample_func()'
         result = get_definition_location(self.project, code, len(code) - 11)
-        self.assertEquals((None, 1), result)
+        self.assertEqual((None, 1), result)
 
     def test_get_definition_location_dotted_names(self):
         code = 'class AClass(object):\n' \
@@ -348,14 +348,14 @@ class CodeAssistTest(unittest.TestCase):
                '        pass\n' \
                'AClass.a_method()'
         result = get_definition_location(self.project, code, len(code) - 3)
-        self.assertEquals((None, 2), result)
+        self.assertEqual((None, 2), result)
 
     def test_get_definition_location_dotted_module_names(self):
         module_resource = testutils.create_module(self.project, 'mod')
         module_resource.write('def a_func():\n    pass\n')
         code = 'import mod\nmod.a_func()'
         result = get_definition_location(self.project, code, len(code) - 3)
-        self.assertEquals((module_resource, 1), result)
+        self.assertEqual((module_resource, 1), result)
 
     def test_get_definition_location_for_nested_packages(self):
         pycore = self.project.pycore
@@ -369,31 +369,31 @@ class CodeAssistTest(unittest.TestCase):
         init_dot_py = pkg2.get_child('__init__.py')
         found_pyname = get_definition_location(self.project, mod1.read(),
                                                mod1.read().index('pkg2') + 1)
-        self.assertEquals(init_dot_py, found_pyname[0])
+        self.assertEqual(init_dot_py, found_pyname[0])
 
     def test_get_definition_location_unknown(self):
         code = 'a_func()\n'
         result = get_definition_location(self.project, code, len(code) - 3)
-        self.assertEquals((None, None), result)
+        self.assertEqual((None, None), result)
 
     def test_get_definition_location_dot_spaces(self):
         code = 'class AClass(object):\n    ' \
                '@staticmethod\n    def a_method():\n' \
                '        pass\nAClass.\\\n     a_method()'
         result = get_definition_location(self.project, code, len(code) - 3)
-        self.assertEquals((None, 2), result)
+        self.assertEqual((None, 2), result)
 
     def test_get_definition_location_dot_line_break_inside_parens(self):
         code = 'class A(object):\n    def a_method(self):\n        pass\n' + \
                '(A.\na_method)'
         result = get_definition_location(self.project, code,
                                          code.rindex('a_method') + 1)
-        self.assertEquals((None, 2), result)
+        self.assertEqual((None, 2), result)
 
     def test_if_scopes_in_other_scopes_for_get_definition_location(self):
         code = 'def f(a_var):\n    pass\na_var = 10\nif True:\n    print a_var\n'
         result = get_definition_location(self.project, code, len(code) - 3)
-        self.assertEquals((None, 3), result)
+        self.assertEqual((None, 3), result)
 
     def test_code_assists_in_parens(self):
         code = 'def a_func(a_var):\n    pass\na_var = 10\na_func(a_'
@@ -415,8 +415,8 @@ class CodeAssistTest(unittest.TestCase):
                '    my_sample_var = 20\n' + \
                '    my_sample_'
         proposals = sorted_proposals(self._assist(code))
-        self.assertEquals('my_sample_var', proposals[0].name)
-        self.assertEquals('my_sample_function', proposals[1].name)
+        self.assertEqual('my_sample_var', proposals[0].name)
+        self.assertEqual('my_sample_function', proposals[1].name)
 
     def test_proposals_sorter_for_methods_and_attributes(self):
         code = 'class A(object):\n' + \
@@ -429,9 +429,9 @@ class CodeAssistTest(unittest.TestCase):
                'a_var = A()\n' + \
                'a_var.my_'
         proposals = sorted_proposals(self._assist(code))
-        self.assertEquals('my_b_func', proposals[0].name)
-        self.assertEquals('my_c_func', proposals[1].name)
-        self.assertEquals('my_a_var', proposals[2].name)
+        self.assertEqual('my_b_func', proposals[0].name)
+        self.assertEqual('my_c_func', proposals[1].name)
+        self.assertEqual('my_a_var', proposals[2].name)
 
     def test_proposals_sorter_for_global_methods_and_funcs(self):
         code = 'def my_b_func(self):\n' + \
@@ -439,8 +439,8 @@ class CodeAssistTest(unittest.TestCase):
                'my_a_var = 10\n' + \
                'my_'
         proposals = sorted_proposals(self._assist(code))
-        self.assertEquals('my_b_func', proposals[0].name)
-        self.assertEquals('my_a_var', proposals[1].name)
+        self.assertEqual('my_b_func', proposals[0].name)
+        self.assertEqual('my_a_var', proposals[1].name)
 
     def test_proposals_sorter_underlined_methods(self):
         code = 'class A(object):\n' + \
@@ -451,8 +451,8 @@ class CodeAssistTest(unittest.TestCase):
                'a_var = A()\n' + \
                'a_var.'
         proposals = sorted_proposals(self._assist(code))
-        self.assertEquals('my_func', proposals[0].name)
-        self.assertEquals('_my_func', proposals[1].name)
+        self.assertEqual('my_func', proposals[0].name)
+        self.assertEqual('_my_func', proposals[1].name)
 
     def test_proposals_sorter_and_scope_prefs(self):
         code = 'my_global_var = 1\n' \
@@ -461,8 +461,8 @@ class CodeAssistTest(unittest.TestCase):
                '    my_'
         result = self._assist(code)
         proposals = sorted_proposals(result, scopepref=['global', 'local'])
-        self.assertEquals('my_global_var', proposals[0].name)
-        self.assertEquals('my_local_var', proposals[1].name)
+        self.assertEqual('my_global_var', proposals[0].name)
+        self.assertEqual('my_local_var', proposals[1].name)
 
     def test_proposals_sorter_and_type_prefs(self):
         code = 'my_global_var = 1\n' \
@@ -471,8 +471,8 @@ class CodeAssistTest(unittest.TestCase):
                'my_'
         result = self._assist(code)
         proposals = sorted_proposals(result, typepref=['instance', 'function'])
-        self.assertEquals('my_global_var', proposals[0].name)
-        self.assertEquals('my_global_func', proposals[1].name)
+        self.assertEqual('my_global_var', proposals[0].name)
+        self.assertEqual('my_global_func', proposals[1].name)
 
     def test_proposals_sorter_and_missing_type_in_typepref(self):
         code = 'my_global_var = 1\n' \
@@ -516,7 +516,7 @@ class CodeAssistTest(unittest.TestCase):
         mod = testutils.create_module(self.project, 'mod')
         mod.write('"""a module"""\n')
         src = 'import mod\nmod'
-        self.assertEquals('a module', get_doc(self.project, src, len(src) - 1))
+        self.assertEqual('a module', get_doc(self.project, src, len(src) - 1))
 
     def test_get_pydoc_for_builtins(self):
         src = 'print(object)\n'
@@ -674,20 +674,20 @@ class CodeAssistTest(unittest.TestCase):
     def test_simple_get_calltips(self):
         src = 'def f():\n    pass\nvar = f()\n'
         doc = get_calltip(self.project, src, src.rindex('f'))
-        self.assertEquals('f()', doc)
+        self.assertEqual('f()', doc)
 
     def test_get_calltips_for_classes(self):
         src = 'class C(object):\n' \
               '    def __init__(self):\n        pass\nC('
         doc = get_calltip(self.project, src, len(src) - 1)
-        self.assertEquals('C.__init__(self)', doc)
+        self.assertEqual('C.__init__(self)', doc)
 
     def test_get_calltips_for_objects_with_call(self):
         src = 'class C(object):\n' \
               '    def __call__(self, p):\n        pass\n' \
               'c = C()\nc(1,'
         doc = get_calltip(self.project, src, src.rindex('c'))
-        self.assertEquals('C.__call__(self, p)', doc)
+        self.assertEqual('C.__call__(self, p)', doc)
 
     def test_get_calltips_and_including_module_name(self):
         src = 'class C(object):\n' \
@@ -696,7 +696,7 @@ class CodeAssistTest(unittest.TestCase):
         mod = testutils.create_module(self.project, 'mod')
         mod.write(src)
         doc = get_calltip(self.project, src, src.rindex('c'), mod)
-        self.assertEquals('mod.C.__call__(self, p)', doc)
+        self.assertEqual('mod.C.__call__(self, p)', doc)
 
     def test_get_calltips_and_including_module_name(self):
         src = 'range()\n'
@@ -709,7 +709,7 @@ class CodeAssistTest(unittest.TestCase):
               '        pass\n' \
               'C().f()'
         doc = get_calltip(self.project, src, src.rindex('f'), remove_self=True)
-        self.assertEquals('C.f()', doc)
+        self.assertEqual('C.f()', doc)
 
     def test_removing_self_parameter_and_more_than_one_parameter(self):
         src = 'class C(object):\n' \
@@ -717,7 +717,7 @@ class CodeAssistTest(unittest.TestCase):
               '        pass\n' \
               'C().f()'
         doc = get_calltip(self.project, src, src.rindex('f'), remove_self=True)
-        self.assertEquals('C.f(p1)', doc)
+        self.assertEqual('C.f(p1)', doc)
 
     def test_lambda_calltip(self):
         src = 'foo = lambda x, y=1: None\n' \
@@ -959,7 +959,7 @@ class CodeAssistInProjectsTest(unittest.TestCase):
                '    def method1(self):\n' \
                '        pass\n' \
                'Sample.me'
-        self.assertEquals(len(code) - 2, starting_offset(code, len(code)))
+        self.assertEqual(len(code) - 2, starting_offset(code, len(code)))
 
     def test_backslash_after_dots(self):
         code = 'class Sample(object):\n' \
@@ -994,13 +994,13 @@ class CodeAssistInProjectsTest(unittest.TestCase):
         code = 'import mod1\nmod1.a_func\n'
         result = get_definition_location(self.project, code,
                                          len(code) - 2, mod2)
-        self.assertEquals((mod1, 1), result)
+        self.assertEqual((mod1, 1), result)
 
     def test_get_definition_location_for_builtins(self):
         code = 'import sys\n'
         result = get_definition_location(self.project, code,
                                          len(code) - 2)
-        self.assertEquals((None, None), result)
+        self.assertEqual((None, None), result)
 
     def test_get_doc_on_relative_imports(self):
         pkg = testutils.create_package(self.project, 'pkg')
@@ -1052,8 +1052,13 @@ class CodeAssistInProjectsTest(unittest.TestCase):
 
     def test_starting_expression(self):
         code = 'l = list()\nl.app'
-        self.assertEquals('l.app', starting_expression(code, len(code)))
+        self.assertEqual('l.app', starting_expression(code, len(code)))
 
+    def test_with_variable_completion_proposal(self):
+        code = 'def test_with_statement():\n  with open("output.txt", "w") as fout:\n    ' \
+               'fo'
+        result = self._assist(code)
+        self.assert_completion_in_result('fout', 'local', result)
 
 def suite():
     result = unittest.TestSuite()
