@@ -21,37 +21,37 @@ class PyCoreTest(unittest.TestCase):
     def test_simple_module(self):
         testutils.create_module(self.project, 'mod')
         result = self.pycore.get_module('mod')
-        self.assertEquals(get_base_type('Module'), result.type)
-        self.assertEquals(0, len(result.get_attributes()))
+        self.assertEqual(get_base_type('Module'), result.type)
+        self.assertEqual(0, len(result.get_attributes()))
 
     def test_nested_modules(self):
         pkg = testutils.create_package(self.project, 'pkg')
         mod = testutils.create_module(self.project, 'mod', pkg)
         package = self.pycore.get_module('pkg')
-        self.assertEquals(get_base_type('Module'), package.get_type())
-        self.assertEquals(1, len(package.get_attributes()))
+        self.assertEqual(get_base_type('Module'), package.get_type())
+        self.assertEqual(1, len(package.get_attributes()))
         module = package['mod'].get_object()
-        self.assertEquals(get_base_type('Module'), module.get_type())
+        self.assertEqual(get_base_type('Module'), module.get_type())
 
     def test_package(self):
         pkg = testutils.create_package(self.project, 'pkg')
         mod = testutils.create_module(self.project, 'mod', pkg)
         result = self.pycore.get_module('pkg')
-        self.assertEquals(get_base_type('Module'), result.type)
+        self.assertEqual(get_base_type('Module'), result.type)
 
     def test_simple_class(self):
         mod = testutils.create_module(self.project, 'mod')
         mod.write('class SampleClass(object):\n    pass\n')
         mod_element = self.pycore.get_module('mod')
         result = mod_element['SampleClass'].get_object()
-        self.assertEquals(get_base_type('Type'), result.get_type())
+        self.assertEqual(get_base_type('Type'), result.get_type())
 
     def test_simple_function(self):
         mod = testutils.create_module(self.project, 'mod')
         mod.write('def sample_function():\n    pass\n')
         mod_element = self.pycore.get_module('mod')
         result = mod_element['sample_function'].get_object()
-        self.assertEquals(get_base_type('Function'), result.get_type())
+        self.assertEqual(get_base_type('Function'), result.get_type())
 
     def test_class_methods(self):
         mod = testutils.create_module(self.project, 'mod')
@@ -63,7 +63,7 @@ class PyCoreTest(unittest.TestCase):
         sample_class = mod_element['SampleClass'].get_object()
         self.assertTrue('sample_method' in sample_class)
         method = sample_class['sample_method'].get_object()
-        self.assertEquals(get_base_type('Function'), method.get_type())
+        self.assertEqual(get_base_type('Function'), method.get_type())
 
     def test_global_variables(self):
         mod = testutils.create_module(self.project, 'mod')
@@ -108,7 +108,7 @@ class PyCoreTest(unittest.TestCase):
         mod_element = self.pycore.get_module('mod')
         sample_class = mod_element['SampleClass'].get_object()
         var = sample_class['InnerClass'].get_object()
-        self.assertEquals(get_base_type('Type'), var.get_type())
+        self.assertEqual(get_base_type('Type'), var.get_type())
 
     @testutils.assert_raises(exceptions.ModuleNotFoundError)
     def test_non_existent_module(self):
@@ -120,7 +120,7 @@ class PyCoreTest(unittest.TestCase):
         mod.write('import mod1\n')
         module = self.pycore.get_module('mod2')
         imported_sys = module['mod1'].get_object()
-        self.assertEquals(get_base_type('Module'), imported_sys.get_type())
+        self.assertEqual(get_base_type('Module'), imported_sys.get_type())
 
     def test_imported_as_names(self):
         testutils.create_module(self.project, 'mod1')
@@ -128,12 +128,12 @@ class PyCoreTest(unittest.TestCase):
         mod.write('import mod1 as my_import\n')
         module = self.pycore.get_module('mod2')
         imported_mod = module['my_import'].get_object()
-        self.assertEquals(get_base_type('Module'), imported_mod.get_type())
+        self.assertEqual(get_base_type('Module'), imported_mod.get_type())
 
     def test_get_string_module(self):
         mod = self.pycore.get_string_module('class Sample(object):\n    pass\n')
         sample_class = mod['Sample'].get_object()
-        self.assertEquals(get_base_type('Type'), sample_class.get_type())
+        self.assertEqual(get_base_type('Type'), sample_class.get_type())
 
     def test_get_string_module_with_extra_spaces(self):
         mod = self.pycore.get_string_module('a = 10\n    ')
@@ -142,13 +142,13 @@ class PyCoreTest(unittest.TestCase):
         code = 'def func(param1, param2=10, *param3, **param4):\n    pass'
         mod = self.pycore.get_string_module(code)
         sample_function = mod['func']
-        self.assertEquals(['param1', 'param2', 'param3', 'param4'],
+        self.assertEqual(['param1', 'param2', 'param3', 'param4'],
                           sample_function.get_object().get_param_names())
 
     # FIXME: Not found modules
     def xxx_test_not_found_module_is_module(self):
         mod = self.pycore.get_string_module('import doesnotexist\n')
-        self.assertEquals(get_base_type('Module'),
+        self.assertEqual(get_base_type('Module'),
                           mod['doesnotexist'].
                           get_object().get_type())
 
@@ -166,7 +166,7 @@ class PyCoreTest(unittest.TestCase):
         mod = self.pycore.get_string_module(code)
         derived = mod['Derived'].get_object()
         self.assertTrue('method' in derived)
-        self.assertEquals(get_base_type('Function'),
+        self.assertEqual(get_base_type('Function'),
                           derived['method'].get_object().get_type())
 
     def test_inheriting_multiple_base_class_attributes(self):
@@ -185,7 +185,7 @@ class PyCoreTest(unittest.TestCase):
         mod = self.pycore.get_string_module(code)
         base1 = mod['Base1'].get_object()
         derived = mod['Derived'].get_object()
-        self.assertEquals(base1['method'].get_object(),
+        self.assertEqual(base1['method'].get_object(),
                           derived['method'].get_object())
 
     def test_inheriting_unknown_base_class(self):
@@ -199,49 +199,49 @@ class PyCoreTest(unittest.TestCase):
     def test_module_creation(self):
         new_module = testutils.create_module(self.project, 'module')
         self.assertFalse(new_module.is_folder())
-        self.assertEquals(self.project.get_resource('module.py'), new_module)
+        self.assertEqual(self.project.get_resource('module.py'), new_module)
 
     def test_packaged_module_creation(self):
         package = self.project.root.create_folder('package')
         new_module = testutils.create_module(self.project, 'package.module')
-        self.assertEquals(self.project.get_resource('package/module.py'), new_module)
+        self.assertEqual(self.project.get_resource('package/module.py'), new_module)
 
     def test_packaged_module_creation_with_nested_src(self):
         src = self.project.root.create_folder('src')
         package = src.create_folder('pkg')
         new_module = testutils.create_module(self.project, 'pkg.mod', src)
-        self.assertEquals(self.project.get_resource('src/pkg/mod.py'), new_module)
+        self.assertEqual(self.project.get_resource('src/pkg/mod.py'), new_module)
 
     def test_package_creation(self):
         new_package = testutils.create_package(self.project, 'pkg')
         self.assertTrue(new_package.is_folder())
-        self.assertEquals(self.project.get_resource('pkg'), new_package)
-        self.assertEquals(self.project.get_resource('pkg/__init__.py'),
+        self.assertEqual(self.project.get_resource('pkg'), new_package)
+        self.assertEqual(self.project.get_resource('pkg/__init__.py'),
                           new_package.get_child('__init__.py'));
 
     def test_nested_package_creation(self):
         package = testutils.create_package(self.project, 'pkg1')
         nested_package = testutils.create_package(self.project, 'pkg1.pkg2')
-        self.assertEquals(self.project.get_resource('pkg1/pkg2'), nested_package)
+        self.assertEqual(self.project.get_resource('pkg1/pkg2'), nested_package)
 
     def test_packaged_package_creation_with_nested_src(self):
         src = self.project.root.create_folder('src')
         package = testutils.create_package(self.project, 'pkg1', src)
         nested_package = testutils.create_package(self.project, 'pkg1.pkg2', src)
-        self.assertEquals(self.project.get_resource('src/pkg1/pkg2'), nested_package)
+        self.assertEqual(self.project.get_resource('src/pkg1/pkg2'), nested_package)
 
     def test_find_module(self):
         src = self.project.root.create_folder('src')
         samplemod = testutils.create_module(self.project, 'samplemod', src)
         found_module = self.pycore.find_module('samplemod')
-        self.assertEquals(samplemod, found_module)
+        self.assertEqual(samplemod, found_module)
 
     def test_find_nested_module(self):
         src = self.project.root.create_folder('src')
         samplepkg = testutils.create_package(self.project, 'samplepkg', src)
         samplemod = testutils.create_module(self.project, 'samplemod', samplepkg)
         found_module = self.pycore.find_module('samplepkg.samplemod')
-        self.assertEquals(samplemod, found_module)
+        self.assertEqual(samplemod, found_module)
 
     def test_find_multiple_module(self):
         src = self.project.root.create_folder('src')
@@ -258,14 +258,14 @@ class PyCoreTest(unittest.TestCase):
         src = self.project.root
         samplepkg = testutils.create_package(self.project, 'samplepkg', src)
         found_module = self.pycore.find_module('samplepkg')
-        self.assertEquals(samplepkg, found_module)
+        self.assertEqual(samplepkg, found_module)
 
     def test_find_module_when_module_and_package_with_the_same_name(self):
         src = self.project.root
         samplemod = testutils.create_module(self.project, 'sample', src)
         samplepkg = testutils.create_package(self.project, 'sample', src)
         found_module = self.pycore.find_module('sample')
-        self.assertEquals(samplepkg, found_module)
+        self.assertEqual(samplepkg, found_module)
 
     def test_source_folders_preference(self):
         pkg1 = testutils.create_package(self.project, 'pkg1')
@@ -279,26 +279,26 @@ class PyCoreTest(unittest.TestCase):
         self.assertEqual(self.project.pycore.find_module('lost'), lost)
 
     def test_getting_empty_source_folders(self):
-        self.assertEquals([], self.pycore.get_source_folders())
+        self.assertEqual([], self.pycore.get_source_folders())
 
     def test_root_source_folder(self):
         self.project.root.create_file('sample.py')
         source_folders = self.pycore.get_source_folders()
-        self.assertEquals(1, len(source_folders))
+        self.assertEqual(1, len(source_folders))
         self.assertTrue(self.project.root in source_folders)
 
     def test_root_source_folder2(self):
         self.project.root.create_file('mod1.py')
         self.project.root.create_file('mod2.py')
         source_folders = self.pycore.get_source_folders()
-        self.assertEquals(1, len(source_folders))
+        self.assertEqual(1, len(source_folders))
         self.assertTrue(self.project.root in source_folders)
 
     def test_src_source_folder(self):
         src = self.project.root.create_folder('src')
         src.create_file('sample.py')
         source_folders = self.pycore.get_source_folders()
-        self.assertEquals(1, len(source_folders))
+        self.assertEqual(1, len(source_folders))
         self.assertTrue(self.project.get_resource('src') in source_folders)
 
     def test_packages(self):
@@ -306,7 +306,7 @@ class PyCoreTest(unittest.TestCase):
         pkg = src.create_folder('package')
         pkg.create_file('__init__.py')
         source_folders = self.pycore.get_source_folders()
-        self.assertEquals(1, len(source_folders))
+        self.assertEqual(1, len(source_folders))
         self.assertTrue(src in source_folders)
 
     def test_multi_source_folders(self):
@@ -316,7 +316,7 @@ class PyCoreTest(unittest.TestCase):
         test = self.project.root.create_folder('test')
         test.create_file('alltests.py')
         source_folders = self.pycore.get_source_folders()
-        self.assertEquals(2, len(source_folders))
+        self.assertEqual(2, len(source_folders))
         self.assertTrue(src in source_folders)
         self.assertTrue(test in source_folders)
 
@@ -326,43 +326,43 @@ class PyCoreTest(unittest.TestCase):
         package = testutils.create_package(self.project, 'package', src)
         mod2 = testutils.create_module(self.project, 'mod2', package)
         source_folders = self.pycore.get_source_folders()
-        self.assertEquals(2, len(source_folders))
+        self.assertEqual(2, len(source_folders))
         self.assertTrue(self.project.root in source_folders and \
                         src in source_folders)
 
     def test_get_pyname_definition_location(self):
         mod = self.pycore.get_string_module('a_var = 20\n')
         a_var = mod['a_var']
-        self.assertEquals((mod, 1), a_var.get_definition_location())
+        self.assertEqual((mod, 1), a_var.get_definition_location())
 
     def test_get_pyname_definition_location_functions(self):
         mod = self.pycore.get_string_module('def a_func():\n    pass\n')
         a_func = mod['a_func']
-        self.assertEquals((mod, 1), a_func.get_definition_location())
+        self.assertEqual((mod, 1), a_func.get_definition_location())
 
     def test_get_pyname_definition_location_class(self):
         code = 'class AClass(object):\n    pass\n\n'
         mod = self.pycore.get_string_module(code)
         a_class = mod['AClass']
-        self.assertEquals((mod, 1), a_class.get_definition_location())
+        self.assertEqual((mod, 1), a_class.get_definition_location())
 
     def test_get_pyname_definition_location_local_variables(self):
         mod = self.pycore.get_string_module('def a_func():\n    a_var = 10\n')
         a_func_scope = mod.get_scope().get_scopes()[0]
         a_var = a_func_scope['a_var']
-        self.assertEquals((mod, 2), a_var.get_definition_location())
+        self.assertEqual((mod, 2), a_var.get_definition_location())
 
     def test_get_pyname_definition_location_reassigning(self):
         mod = self.pycore.get_string_module('a_var = 20\na_var=30\n')
         a_var = mod['a_var']
-        self.assertEquals((mod, 1), a_var.get_definition_location())
+        self.assertEqual((mod, 1), a_var.get_definition_location())
 
     def test_get_pyname_definition_location_importes(self):
         module = testutils.create_module(self.project, 'mod')
         mod = self.pycore.get_string_module('import mod\n')
         imported_module = self.pycore.get_module('mod')
         module_pyname = mod['mod']
-        self.assertEquals((imported_module, 1),
+        self.assertEqual((imported_module, 1),
                           module_pyname.get_definition_location())
 
     def test_get_pyname_definition_location_imports(self):
@@ -371,23 +371,23 @@ class PyCoreTest(unittest.TestCase):
         imported_module = self.pycore.get_module('mod')
         mod = self.pycore.get_string_module('from mod import a_func\n')
         a_func = mod['a_func']
-        self.assertEquals((imported_module, 2), a_func.get_definition_location())
+        self.assertEqual((imported_module, 2), a_func.get_definition_location())
 
     def test_get_pyname_definition_location_parameters(self):
         code = 'def a_func(param1, param2):\n    a_var = param\n'
         mod = self.pycore.get_string_module(code)
         a_func_scope = mod.get_scope().get_scopes()[0]
         param1 = a_func_scope['param1']
-        self.assertEquals((mod, 1), param1.get_definition_location())
+        self.assertEqual((mod, 1), param1.get_definition_location())
         param2 = a_func_scope['param2']
-        self.assertEquals((mod, 1), param2.get_definition_location())
+        self.assertEqual((mod, 1), param2.get_definition_location())
 
     def test_module_get_resource(self):
         module_resource = testutils.create_module(self.project, 'mod')
         module = self.pycore.get_module('mod')
-        self.assertEquals(module_resource, module.get_resource())
+        self.assertEqual(module_resource, module.get_resource())
         string_module = self.pycore.get_string_module('from mod import a_func\n')
-        self.assertEquals(None, string_module.get_resource())
+        self.assertEqual(None, string_module.get_resource())
 
     def test_get_pyname_definition_location_class2(self):
         code = 'class AClass(object):\n' \
@@ -396,17 +396,17 @@ class PyCoreTest(unittest.TestCase):
         mod = self.pycore.get_string_module(code)
         a_class = mod['AClass'].get_object()
         an_attr = a_class['an_attr']
-        self.assertEquals((mod, 3), an_attr.get_definition_location())
+        self.assertEqual((mod, 3), an_attr.get_definition_location())
 
     def test_import_not_found_module_get_definition_location(self):
         mod = self.pycore.get_string_module('import doesnotexist\n')
         does_not_exist = mod['doesnotexist']
-        self.assertEquals((None, None), does_not_exist.get_definition_location())
+        self.assertEqual((None, None), does_not_exist.get_definition_location())
 
     def test_from_not_found_module_get_definition_location(self):
         mod = self.pycore.get_string_module('from doesnotexist import Sample\n')
         sample = mod['Sample']
-        self.assertEquals((None, None), sample.get_definition_location())
+        self.assertEqual((None, None), sample.get_definition_location())
 
     def test_from_package_import_module_get_definition_location(self):
         pkg = testutils.create_package(self.project, 'pkg')
@@ -414,20 +414,20 @@ class PyCoreTest(unittest.TestCase):
         pkg_mod = self.pycore.get_module('pkg.mod')
         mod = self.pycore.get_string_module('from pkg import mod\n')
         imported_mod = mod['mod']
-        self.assertEquals((pkg_mod, 1),
+        self.assertEqual((pkg_mod, 1),
                           imported_mod.get_definition_location())
 
     def test_get_module_for_defined_pyobjects(self):
         mod = self.pycore.get_string_module('class AClass(object):\n    pass\n')
         a_class = mod['AClass'].get_object()
-        self.assertEquals(mod, a_class.get_module())
+        self.assertEqual(mod, a_class.get_module())
 
     def test_get_definition_location_for_packages(self):
         pkg = testutils.create_package(self.project, 'pkg')
         init_module = self.pycore.get_module('pkg.__init__')
         mod = self.pycore.get_string_module('import pkg\n')
         pkg_pyname = mod['pkg']
-        self.assertEquals((init_module, 1), pkg_pyname.get_definition_location())
+        self.assertEqual((init_module, 1), pkg_pyname.get_definition_location())
 
     def test_get_definition_location_for_filtered_packages(self):
         pkg = testutils.create_package(self.project, 'pkg')
@@ -435,7 +435,7 @@ class PyCoreTest(unittest.TestCase):
         init_module = self.pycore.get_module('pkg.__init__')
         mod = self.pycore.get_string_module('import pkg.mod')
         pkg_pyname = mod['pkg']
-        self.assertEquals((init_module, 1), pkg_pyname.get_definition_location())
+        self.assertEqual((init_module, 1), pkg_pyname.get_definition_location())
 
     def test_out_of_project_modules(self):
         scope = self.pycore.get_string_scope('import rope.base.project as project\n')
@@ -454,7 +454,7 @@ class PyCoreTest(unittest.TestCase):
         global_var = mod['a_var']
         func_scope = mod['a_func'].get_object().get_scope()
         local_var = func_scope['a_var']
-        self.assertEquals(global_var, local_var)
+        self.assertEqual(global_var, local_var)
 
     def test_not_leaking_for_vars_inside_parent_scope(self):
         mod = testutils.create_module(self.project, 'mod')
@@ -540,7 +540,7 @@ class PyCoreTest(unittest.TestCase):
         pymod = self.pycore.get_string_module(code)
         a_class = pymod['A'].get_object()
         var = pymod['var'].get_object()
-        self.assertEquals(a_class, var.get_type())
+        self.assertEqual(a_class, var.get_type())
 
     @testutils.run_only_for_25
     def test_with_statement_with_no_vars(self):
@@ -557,20 +557,20 @@ class PyCoreTest(unittest.TestCase):
                '    myvar = 1\n'
         mod = self.pycore.get_string_module(code)
         a_var = mod['myvar']
-        self.assertEquals((mod, 4), a_var.get_definition_location())
+        self.assertEqual((mod, 4), a_var.get_definition_location())
 
     def test_check_names_defined_in_whiles(self):
         mod = self.pycore.get_string_module('while False:\n    myvar = 1\n')
         a_var = mod['myvar']
-        self.assertEquals((mod, 2), a_var.get_definition_location())
+        self.assertEqual((mod, 2), a_var.get_definition_location())
 
     def test_get_definition_location_in_tuple_assnames(self):
         mod = self.pycore.get_string_module(
             'def f(x):\n    x.z, a = range(2)\n')
         x = mod['f'].get_object().get_scope()['x']
         a = mod['f'].get_object().get_scope()['a']
-        self.assertEquals((mod, 1), x.get_definition_location())
-        self.assertEquals((mod, 2), a.get_definition_location())
+        self.assertEqual((mod, 1), x.get_definition_location())
+        self.assertEqual((mod, 2), a.get_definition_location())
 
     @testutils.assert_raises(exceptions.ModuleSyntaxError)
     def test_syntax_errors_in_code(self):
@@ -580,7 +580,7 @@ class PyCoreTest(unittest.TestCase):
         try:
             mod = self.pycore.get_string_module('xyx print\n')
         except exceptions.ModuleSyntaxError as e:
-            self.assertEquals(1, e.lineno)
+            self.assertEqual(1, e.lineno)
 
     def test_no_exceptions_on_module_encoding_problems(self):
         mod = testutils.create_module(self.project, 'mod')
@@ -643,7 +643,7 @@ class PyCoreTest(unittest.TestCase):
         mod1 = testutils.create_module(self.project, 'mod1')
         mod1.write('var1 = ""\nvar2 = ""\n')
         pymod1 = self.pycore.resource_to_pyobject(mod1)
-        self.assertEquals(pymod1['var1'].get_object(),
+        self.assertEqual(pymod1['var1'].get_object(),
                           pymod1['var2'].get_object())
 
 
@@ -673,19 +673,19 @@ class PyCoreInProjectsTest(unittest.TestCase):
     def test_simple_import(self):
         mod = self.pycore.get_string_module('import samplemod\n')
         samplemod = mod['samplemod'].get_object()
-        self.assertEquals(get_base_type('Module'), samplemod.get_type())
+        self.assertEqual(get_base_type('Module'), samplemod.get_type())
 
     def test_from_import_class(self):
         mod = self.pycore.get_string_module('from samplemod import SampleClass\n')
         result = mod['SampleClass'].get_object()
-        self.assertEquals(get_base_type('Type'), result.get_type())
+        self.assertEqual(get_base_type('Type'), result.get_type())
         self.assertTrue('sample_func' not in mod.get_attributes())
 
     def test_from_import_star(self):
         mod = self.pycore.get_string_module('from samplemod import *\n')
-        self.assertEquals(get_base_type('Type'),
+        self.assertEqual(get_base_type('Type'),
                           mod['SampleClass'].get_object().get_type())
-        self.assertEquals(get_base_type('Function'),
+        self.assertEqual(get_base_type('Function'),
                           mod['sample_func'].get_object().get_type())
         self.assertTrue(mod['sample_var'] is not None)
 
@@ -695,7 +695,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         mod = self.pycore.get_string_module(code)
         samplemod = self.pycore.get_module('samplemod')
         sample_class = samplemod['SampleClass'].get_object()
-        self.assertNotEquals(sample_class,
+        self.assertNotEqual(sample_class,
                              mod.get_attributes()['SampleClass'].get_object())
 
     def test_from_import_star_not_imporing_underlined(self):
@@ -708,7 +708,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
 
     def test_from_package_import_mod(self):
         mod = self.pycore.get_string_module('from package import nestedmod\n')
-        self.assertEquals(get_base_type('Module'),
+        self.assertEqual(get_base_type('Module'),
                           mod['nestedmod'].get_object().get_type())
 
     # XXX: Deciding to import everything on import start from packages
@@ -723,7 +723,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
     def test_from_import_function(self):
         code = 'def f():\n    from samplemod import SampleClass\n'
         scope = self.pycore.get_string_scope(code)
-        self.assertEquals(get_base_type('Type'),
+        self.assertEqual(get_base_type('Type'),
                           scope.get_scopes()[0]['SampleClass'].
                           get_object().get_type())
 
@@ -756,7 +756,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         mod2 = testutils.create_module(self.project, 'mod2', pkg)
         mod = self.pycore.get_string_module('import pkg.mod1\nimport pkg.mod2\n')
         package = mod['pkg'].get_object()
-        self.assertEquals(2, len(package.get_attributes()))
+        self.assertEqual(2, len(package.get_attributes()))
         self.assertTrue('mod1' in package and
                         'mod2' in package)
 
@@ -769,7 +769,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         mod = self.pycore.get_string_module(code)
         package1 = mod['pkg1'].get_object()
         package2 = package1['pkg2'].get_object()
-        self.assertEquals(2, len(package2.get_attributes()))
+        self.assertEqual(2, len(package2.get_attributes()))
         self.assertTrue('mod1' in package2 and 'mod2' in package2)
 
     def test_multi_dot_imports_as(self):
@@ -787,7 +787,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         module = testutils.create_module(self.project, 'mod', pkg2)
         mod = self.pycore.get_string_module('from pkg1 import pkg2\n')
         package = mod['pkg2']
-        self.assertEquals(0, len(package.get_attributes()))
+        self.assertEqual(0, len(package.get_attributes()))
 
     def test_invalidating_cache_after_resource_change(self):
         module = testutils.create_module(self.project, 'mod')
@@ -825,7 +825,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         code = 'from doesnotexistmod import DoesNotExistClass\n'
         mod = self.pycore.get_string_module(code)
         self.assertTrue('DoesNotExistClass' in mod)
-        self.assertEquals(get_base_type('Unknown'),
+        self.assertEqual(get_base_type('Unknown'),
                           mod['DoesNotExistClass'].
                           get_object().get_type())
 
@@ -833,18 +833,18 @@ class PyCoreInProjectsTest(unittest.TestCase):
         code = 'from samplemod import DoesNotExistClass\n'
         mod = self.pycore.get_string_module(code)
         self.assertTrue('DoesNotExistClass' in mod)
-        self.assertEquals(get_base_type('Unknown'),
+        self.assertEqual(get_base_type('Unknown'),
                           mod['DoesNotExistClass'].
                           get_object().get_type())
 
     def test_not_considering_imported_names_as_sub_scopes(self):
         code = 'from samplemod import SampleClass\n'
         scope = self.pycore.get_string_scope(code)
-        self.assertEquals(0, len(scope.get_scopes()))
+        self.assertEqual(0, len(scope.get_scopes()))
 
     def test_not_considering_imported_modules_as_sub_scopes(self):
         scope = self.pycore.get_string_scope('import samplemod\n')
-        self.assertEquals(0, len(scope.get_scopes()))
+        self.assertEqual(0, len(scope.get_scopes()))
 
     def test_inheriting_dotted_base_class(self):
         code = 'import samplemod\n' \
@@ -861,7 +861,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         scope = self.pycore.get_string_scope(code)
         sample_class = scope['Sample'].get_object()
         func_scope = scope.get_scopes()[0].get_scopes()[0]
-        self.assertEquals(sample_class,
+        self.assertEqual(sample_class,
                           func_scope['self'].get_object().get_type())
         self.assertTrue('func' in func_scope['self'].
                                 get_object())
@@ -884,7 +884,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         scope = self.pycore.get_string_scope(code)
         sample_class = scope['Sample'].get_object()
         func_scope = scope.get_scopes()[0].get_scopes()[0]
-        self.assertNotEquals(sample_class,
+        self.assertNotEqual(sample_class,
                              func_scope['self'].get_object().get_type())
 
     def test_location_of_imports_when_importing(self):
@@ -893,7 +893,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         scope = self.pycore.get_string_scope('from mod import SampleClass\n')
         sample_class = scope['SampleClass']
         samplemod = self.pycore.get_module('samplemod')
-        self.assertEquals((samplemod, 1), sample_class.get_definition_location())
+        self.assertEqual((samplemod, 1), sample_class.get_definition_location())
 
     def test_nested_modules(self):
         pkg = testutils.create_package(self.project, 'pkg')
@@ -901,7 +901,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         imported_module = self.pycore.get_module('pkg.mod')
         scope = self.pycore.get_string_scope('import pkg.mod\n')
         mod_pyobject = scope['pkg'].get_object()['mod']
-        self.assertEquals((imported_module, 1),
+        self.assertEqual((imported_module, 1),
                           mod_pyobject.get_definition_location())
 
     def test_reading_init_dot_py(self):
@@ -918,7 +918,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         mod2.write('import mod1\n')
         mod1_object = self.pycore.resource_to_pyobject(mod1)
         mod2_object = self.pycore.resource_to_pyobject(mod2)
-        self.assertEquals(mod1_object, mod2_object.get_attributes()['mod1'].get_object())
+        self.assertEqual(mod1_object, mod2_object.get_attributes()['mod1'].get_object())
 
     def test_relative_froms(self):
         pkg = testutils.create_package(self.project, 'pkg')
@@ -928,7 +928,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         mod2.write('from mod1 import a_func\n')
         mod1_object = self.pycore.resource_to_pyobject(mod1)
         mod2_object = self.pycore.resource_to_pyobject(mod2)
-        self.assertEquals(mod1_object['a_func'].get_object(),
+        self.assertEqual(mod1_object['a_func'].get_object(),
                           mod2_object['a_func'].get_object())
 
     def test_relative_imports_for_string_modules(self):
@@ -938,7 +938,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         mod2.write('import mod1\n')
         mod1_object = self.pycore.resource_to_pyobject(mod1)
         mod2_object = self.pycore.get_string_module(mod2.read(), mod2)
-        self.assertEquals(mod1_object, mod2_object['mod1'].get_object())
+        self.assertEqual(mod1_object, mod2_object['mod1'].get_object())
 
     def test_relative_imports_for_string_scopes(self):
         pkg = testutils.create_package(self.project, 'pkg')
@@ -947,7 +947,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         mod2.write('import mod1\n')
         mod1_object = self.pycore.resource_to_pyobject(mod1)
         mod2_scope = self.pycore.get_string_scope(mod2.read(), mod2)
-        self.assertEquals(mod1_object, mod2_scope['mod1'].get_object())
+        self.assertEqual(mod1_object, mod2_scope['mod1'].get_object())
 
     @testutils.run_only_for_25
     def test_new_style_relative_imports(self):
@@ -957,7 +957,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         mod2.write('from . import mod1\n')
         mod1_object = self.pycore.resource_to_pyobject(mod1)
         mod2_object = self.pycore.resource_to_pyobject(mod2)
-        self.assertEquals(mod1_object, mod2_object['mod1'].get_object())
+        self.assertEqual(mod1_object, mod2_object['mod1'].get_object())
 
     @testutils.run_only_for_25
     def test_new_style_relative_imports2(self):
@@ -968,7 +968,7 @@ class PyCoreInProjectsTest(unittest.TestCase):
         mod2.write('from ..mod1 import a_func\n')
         mod1_object = self.pycore.resource_to_pyobject(mod1)
         mod2_object = self.pycore.resource_to_pyobject(mod2)
-        self.assertEquals(mod1_object['a_func'].get_object(),
+        self.assertEqual(mod1_object['a_func'].get_object(),
                           mod2_object['a_func'].get_object())
 
     def test_invalidating_cache_for_from_imports_after_resource_change(self):
@@ -979,11 +979,11 @@ class PyCoreInProjectsTest(unittest.TestCase):
 
         pymod1 = self.pycore.get_module('mod1')
         pymod2 = self.pycore.get_module('mod2')
-        self.assertEquals(pymod1['a_func'].get_object(),
+        self.assertEqual(pymod1['a_func'].get_object(),
                           pymod2['a_func'].get_object())
         mod2.write(mod2.read() + '\n')
         pymod2 = self.pycore.get_module('mod2')
-        self.assertEquals(pymod1['a_func'].get_object(),
+        self.assertEqual(pymod1['a_func'].get_object(),
                           pymod2['a_func'].get_object())
 
     def test_invalidating_superclasses_after_change(self):
