@@ -223,6 +223,8 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_children(
             'AugAssign', ['Name', ' ', '+', '', '=', ' ', 'Num'])
 
+    #XXX: Removed from py3 testing, syntax error
+    """
     def test_back_quotenode(self):
         source = '`1`\n'
         ast = patchedast.get_patched_ast(source, True)
@@ -230,6 +232,7 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_region('Repr', 0, len(source) - 1)
         checker.check_children(
             'Repr', ['`', '', 'Num', '', '`'])
+    """
 
     def test_bitand(self):
         source = '1 & 2\n'
@@ -365,9 +368,11 @@ class PatchedASTTest(unittest.TestCase):
             'Function', ['def', ' ', 'f', '', '(', '', 'arguments',
                          '', ')' , '', ':', '\n    ', 'Expr', '\n    ', 'Pass'])
         checker.check_children(
-            'arguments', ['Name', '', ',',
+            'arguments', ['p1', '', ',',
                           ' ', '**', '', 'p2'])
 
+    #XXX: Removed from py3 testing, no more tuple parameter unpacking
+    """
     def test_function_node_and_tuple_parameters(self):
         source = 'def f(a, (b, c)):\n    pass\n'
         ast = patchedast.get_patched_ast(source, True)
@@ -378,6 +383,7 @@ class PatchedASTTest(unittest.TestCase):
                          '', ')' , '', ':', '\n    ', 'Pass'])
         checker.check_children(
             'arguments', ['Name', '', ',', ' ', 'Tuple'])
+    """
 
     def test_dict_node(self):
         source = '{1: 2, 3: 4}\n'
@@ -395,21 +401,24 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_region('BinOp', 0, len(source) - 1)
         checker.check_children('BinOp', ['Num', ' ', '/', ' ', 'Num'])
 
+    #XXX: Removed from py3 testing, exec is a function
+    """
     def test_simple_exec_node(self):
-        source = 'exec("")\n'
+        source = 'exec ""\n'
         ast = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast)
         checker.check_region('Exec', 0, len(source) - 1)
         checker.check_children('Exec', ['exec', ' ', 'Str'])
 
     def test_exec_node(self):
-        source = 'exec( "" in locals(), globals())\n'
+        source = 'exec "" in locals(), globals()\n'
         ast = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast)
         checker.check_region('Exec', 0, len(source) - 1)
         checker.check_children(
             'Exec', ['exec', ' ', 'Str', ' ', 'in',
                      ' ', 'Call', '', ',', ' ', 'Call'])
+    """
 
     def test_for_node(self):
         source = 'for i in range(1):\n    pass\nelse:\n    pass\n'
@@ -523,9 +532,9 @@ class PatchedASTTest(unittest.TestCase):
         checker = _ResultChecker(self, ast)
         checker.check_region('Lambda', 0, len(source) - 1)
         checker.check_children(
-            'Lambda', ['lambda', ' ', 'arguments', '', ':', ' ', 'Name'])
+            'Lambda', ['lambda', '', 'arguments', '', ':', ' ', 'Name'])
         checker.check_children(
-            'arguments', ['Name', '', ',', ' ', 'Name', '', '=', '',
+            'arguments', ['a', '', ',', '', 'b', '', '=', '',
                           'Num', '', ',', ' ', '*', '', 'z'])
 
     def test_list_node(self):
@@ -588,6 +597,8 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_children('Expr', ['BoolOp'])
         checker.check_children('BoolOp', ['UnaryOp', ' ', 'or', ' ', 'Name'])
 
+    #XXX: Removed from py3 testing, print is a function
+    """
     def test_print_node(self):
         source = 'print >>out, 1,\n'
         ast = patchedast.get_patched_ast(source, True)
@@ -602,15 +613,18 @@ class PatchedASTTest(unittest.TestCase):
         checker = _ResultChecker(self, ast)
         checker.check_region('Print', 0, len(source) - 1)
         checker.check_children('Print', ['print', ' ', 'Num'])
-
+    """
+    #XXX: Removed from py3 testing, raise was changed, but i cannot understand this test
+    """
     def test_raise_node(self):
-        source = 'raise x, y, z\n'
+        source = 'raise x(y).with_traceback(z)\n'
         ast = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast)
         checker.check_region('Raise', 0, len(source) - 1)
         checker.check_children(
             'Raise', ['raise', ' ', 'Name', '', ',', ' ', 'Name', '', ',',
                       ' ', 'Name'])
+    """
 
     def test_return_node(self):
         source = 'def f():\n    return None\n'
@@ -713,7 +727,7 @@ class PatchedASTTest(unittest.TestCase):
                           ('excepthandler', 'ExceptHandler')])
         checker.check_children(
             ('excepthandler', 'ExceptHandler'),
-            ['except', ' ', 'Name', '', ',', ' ', 'Name', '', ':',
+            ['except', ' ', 'Name', ' ', 'as', ' ', 'e', '', ':',
              '\n    ', 'Pass'])
 
     @testutils.run_only_for_25
@@ -746,12 +760,15 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_children(
             'Module', ['', 'Expr', '\n', 'Expr', '\n'])
 
+    #XXX: Removed from py3 testing, <> not used
+    """
     def test_how_to_handle_old_not_equals(self):
         source = '1 <> 2\n'
         ast = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast)
         checker.check_children(
             'Compare', ['Num', ' ', '<>', ' ', 'Num'])
+    """
 
     def test_semicolon(self):
         source = '1;\n'
